@@ -42,6 +42,7 @@ from xdis.opcodes import opcode_35 as opcode_35
 from xdis.opcodes import opcode_36 as opcode_36
 from xdis.opcodes import opcode_37 as opcode_37
 from xdis.opcodes import opcode_38 as opcode_38
+from xdis.opcodes import opcode_39 as opcode_39
 
 from xdis.opcodes import opcode_26pypy as opcode_26pypy
 from xdis.opcodes import opcode_27pypy as opcode_27pypy
@@ -117,6 +118,8 @@ op_imports = {
     '3.8.0rc1+': opcode_38,
     '3.8.0candidate1': opcode_38,
     '3.8' : opcode_38,
+    '3.9.0alpha1' : opcode_39,
+    '3.9' : opcode_39,
 
     '2.6pypy':  opcode_26pypy,
     '2.7pypy':  opcode_27pypy,
