@@ -134,7 +134,7 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     else:
         co_argcount = unpack("<i", fp.read(4))[0]
 
-    if magic_int in (3412, 3413):
+    if magic_int in (3412, 3413, 3422):
         co_posonlyargcount = unpack("<i", fp.read(4))[0]
     else:
         co_posonlyargcount = None
@@ -233,9 +233,9 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
                     co_cellvars,
                 )
             else:
-                if PYTHON_MAGIC_INT in (3412, 3413):
+                if PYTHON_MAGIC_INT in (3412, 3413, 3422):
                     if co_posonlyargcount is not None:
-                        # Python3.8 to Python3.8: Ok to use native Python3.8's code type
+                        # Python3.8 to Python3.9: Ok to use native Python3.8's code type
                         code = Code(
                             co_argcount,
                             co_posonlyargcount,
@@ -275,6 +275,8 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
                             co_cellvars,
                         )
                 elif co_posonlyargcount is not None:
+                    if not isinstance(co_lnotab, bytes):
+                        co_lnotab = bytes(co_lnotab, encoding="utf-8")
                     code = Code38(
                         co_argcount,
                         co_posonlyargcount,
@@ -289,7 +291,7 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
                         co_filename,
                         co_name,
                         co_firstlineno,
-                        bytes(co_lnotab, encoding="utf-8"),
+                        co_lnotab,
                         co_freevars,
                         co_cellvars,
                     )
@@ -792,7 +794,6 @@ def load_code_internal(fp, magic_int, bytes_for_s=False, code_objects={}):
     global internStrings, internObjects
 
     b1 = ord(fp.read(1))
-
     save_ref = False
     if b1 & FLAG_REF:
         # Since 3.4, "flag" is the marshal.c name
